aboutsummaryrefslogtreecommitdiff
path: root/talk/app/webrtc/jsepsessiondescription.cc
diff options
context:
space:
mode:
authorglaznev@webrtc.org <glaznev@webrtc.org>2015-01-12 17:55:47 +0000
committerglaznev@webrtc.org <glaznev@webrtc.org>2015-01-12 17:55:47 +0000
commitbe40eb05795049271d708140d2c79da6246abf6f (patch)
treee4ce8fe2d59b89144952534c4a799cde5d0c835d /talk/app/webrtc/jsepsessiondescription.cc
parenta525c98ca50ae6af35bd4fac027aa10725dd1399 (diff)
downloadwebrtc-be40eb05795049271d708140d2c79da6246abf6f.tar.gz
Allow 720x1280 frames encoding on Android.
Current maximum encoder width and height for Android is hard-coded to 1280x720, so if device is rotated to portrait orientation only part 720x1280 camera frame is extracted and scaled to 1280x720. Increasing maximum height to 1280 allows feeding video encoder with rotated 720x1280 frames directly without scaling. R=pthatcher@webrtc.org Review URL: https://webrtc-codereview.appspot.com/35739004 git-svn-id: http://webrtc.googlecode.com/svn/trunk@8042 4adac7df-926f-26a2-2b94-8c16560cd09d
Diffstat (limited to 'talk/app/webrtc/jsepsessiondescription.cc')
-rw-r--r--talk/app/webrtc/jsepsessiondescription.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/talk/app/webrtc/jsepsessiondescription.cc b/talk/app/webrtc/jsepsessiondescription.cc
index c318d91dbc..3e85130f1c 100644
--- a/talk/app/webrtc/jsepsessiondescription.cc
+++ b/talk/app/webrtc/jsepsessiondescription.cc
@@ -63,9 +63,10 @@ const char JsepSessionDescription::kDefaultVideoCodecName[] = "VP8";
// Used as default max video codec size before we have it in signaling.
#if defined(ANDROID)
// Limit default max video codec size for Android to avoid
// HW VP8 codec initialization failure for resolution higher than 720p.
const int JsepSessionDescription::kMaxVideoCodecWidth = 1280;
-const int JsepSessionDescription::kMaxVideoCodecHeight = 720;
+const int JsepSessionDescription::kMaxVideoCodecHeight = 1280;
#else
const int JsepSessionDescription::kMaxVideoCodecWidth = 1920;
const int JsepSessionDescription::kMaxVideoCodecHeight = 1080;
@@ -63,9 +63,10 @@ const char JsepSessionDescription::kDefaultVideoCodecName[] = "VP8";
#if defined(ANDROID)
// Limit default max video codec size for Android to avoid
-// HW VP8 codec initialization failure for resolution higher than 720p.
+// HW VP8 codec initialization failure for resolutions higher
+// than 1280x720 or 720x1280.
const int JsepSessionDescription::kMaxVideoCodecWidth = 1280;